@@ -7,7 +7,6 @@ extern crate core;
 extern crate alloc;
 
 use arrayref::array_ref;
-use core::convert::TryFrom;
 use ockam_core::vault::{
     AsymmetricVault, Hasher, PublicKey, SecretType, SecretVault, Signer, SymmetricVault, Verifier,
 };
@@ -133,17 +132,14 @@ impl<D> X3dhVault for D where
 mod tests {
     use super::*;
     use ockam_key_exchange_core::{KeyExchanger, NewKeyExchanger};
-    use ockam_vault::SoftwareVault;
-    use ockam_vault_sync_core::VaultSync;
+    use ockam_vault_sync_core::Vault;
 
     #[allow(non_snake_case)]
     #[test]
     fn full_flow__correct_credentials__keys_should_match() {
         let (mut ctx, mut exec) = ockam_node::start_node();
         exec.execute(async move {
-            let mut vault = VaultSync::create(&ctx, SoftwareVault::default())
-                .await
-                .unwrap();
+            let mut vault = Vault::create();
 
             let key_exchanger = X3dhNewKeyExchanger::new(vault.async_try_clone().await.unwrap());
 
